==> rec10%200.9.1.tar.bz2: rec10 0.9.1/rec10/recdb.py <==
#!/usr/bin/python
# coding: UTF-8
# Rec10 TS Recording Tools
# Copyright (C) 2009-2010 Yukikaze
import chdb
import rec10d
import recdblist

def recreserv(title, chtxt, btime, etime, opt):#optにはa(アニメ)d(副音声)v(xvid)
    rec_reckey("res", title, chtxt, btime, etime, opt)
def auto_keyreserv(keyword, chtxt, btime, etime, deltatime, opt):
    rec10d.rec10db.add_timeline(type=recdblist.REC_AUTO_KEYWORD, chtxt=chtxt, title=keyword, btime=btime, etime=etime, deltatime=deltatime, opt=opt)
def keyreserv(keyword, chtxt, btime, etime, deltatime, opt):
    rec10d.rec10db.add_timeline(type=recdblist.REC_KEYWORD, chtxt=chtxt, title=keyword, btime=btime, etime=etime, deltatime=deltatime, opt=opt)
def everyreserv(keyword, chtxt, btime, etime, deltatime, opt, deltaday):
    rec10d.rec10db.add_timeline(type=recdblist.REC_KEYWORD_EVERY_SOME_DAYS, chtxt=chtxt, title=keyword, btime=btime, etime=etime, deltatime=deltatime, opt=opt, deltaday=deltaday)
def rec_reckey(type, title, chtxt, btime, etime, opt):
    rec10d.rec10db.add_timeline(type=type, chtxt=chtxt, title=title, btime=btime, etime=etime, opt=opt)
def del_reckey(type, title, chtxt, btime):
    rec10d.rec10db.del_timeline(type=type, title=title, chtxt=chtxt, btime=btime)
def add_auto_keyword(chtxt,title,btime,etime):
    rec10d.rec10db.add_auto_timeline_keyword(chtxt, title, btime, etime)
def add_auto_bayes(chtxt,title,btime,etime,point):
    rec10d.rec10db.add_auto_timeline_bayes(chtxt, title, btime, etime,point)
def getnow(dhour):
    dhour = int(dhour)
    dminutes = 60 * dhour
    dminutes = str(dminutes)
    return rec10d.rec10db.select_bytime_timeline(dminutes)
def getnow_minutes(dminutes):
    return rec10d.rec10db.select_bytime_timeline(dminutes)
def countRecNow(dhour):
    d = getnow(dhour)
    ret = 0
    for i in d:
        t = i['type']
        if t == "key" or t == "keyevery" or t == "rec" or t == "res":
            ret = ret + 1
    return ret
def countRecNow_minutes(dminutes):
    d = getnow_minutes(dminutes)
    ret = 0
    for i in d:
        t = i['type']
        if t == "key" or t == "keyevery" or t == "rec" or t == "res":
            ret = ret + 1
    return ret
def countRecNow_minutes_BSCS(dminutes):
    d = getnow_minutes(dminutes)
    ret = 0
    for i in d:
        t = i['type']
        if t == "key" or t == "keyevery" or t == "rec" or t == "res":
            if len(chdb.chtxtsearch(i['chtxt'])['ch']) > 2:
                ret = ret + 1
    return ret
def countRecNow_minutes_TE(dminutes):
    d = getnow_minutes(dminutes)
    ret = 0
    for i in d:
        t = i['type']
        if t == "key" or t == "keyevery" or t == "rec" or t == "res":
            if len(chdb.chtxtsearch(i['chtxt'])['ch']) < 3:
                ret = ret + 1
    return ret
def delete_old(dhour):
    """
    delete keys except recdblist.REC_MISS_ENCODE and recdblist.REC_KEYWORD_EVERY_SOME_DAYS before dhour hours from now.
    """
    rec10d.rec10db.delete_old_timeline(dhour)
def delete_old_auto_keyword(dhour):
    rec10d.rec10db.delete_old_auto_timeline_keyword(dhour)
def delete_old_auto_bayes(dhour):
    rec10d.rec10db.delete_old_auto_timeline_bayes(dhour)
def getall():
    return rec10d.rec10db.select_all_timeline()
def rec_reclog(title,chtxt,btime,etime,opt,exp,longexp,category):
    rec10d.rec10db.add_in_timeline_log(chtxt,title,btime,etime,opt,exp,longexp,category)
def get_key():
    return rec10d.rec10db.select_all_in_auto_jbk_key()

==> rec10%200.9.8.1.tar.bz2: rec10 0.9.8.1/rec10/recdb.py <==
#!/usr/bin/python
# coding: UTF-8
# Rec10 TS Recording Tools
# Copyright (C) 2009-2010 Yukikaze
import chdb
import rec10d
import recdblist

def recreserv(title, chtxt, btime, etime, opt):#optにはa(アニメ)d(副音声)v(xvid)
    rec_reckey("res", title, chtxt, btime, etime, opt)
def auto_keyreserv(keyword, chtxt, btime, etime, deltatime, opt):
    rec10d.rec10db.add_timeline(type=recdblist.REC_AUTO_KEYWORD, chtxt=chtxt, title=keyword, btime=btime, etime=etime, deltatime=deltatime, opt=opt)
def keyreserv(keyword, chtxt, btime, etime, deltatime, opt):
    rec10d.rec10db.add_timeline(type=recdblist.REC_KEYWORD, chtxt=chtxt, title=keyword, btime=btime, etime=etime, deltatime=deltatime, opt=opt)
def everyreserv(keyword, chtxt, btime, etime, deltatime, opt, deltaday,count):
    rec10d.rec10db.add_timeline(type=recdblist.REC_KEYWORD_EVERY_SOME_DAYS, chtxt=chtxt, title=keyword, btime=btime, etime=etime, deltatime=deltatime, opt=opt, deltaday=deltaday,counter=count)
def rec_reckey(type, title, chtxt, btime, etime, opt):
    rec10d.rec10db.add_timeline(type=type, chtxt=chtxt, title=title, btime=btime, etime=etime, opt=opt)
def del_reckey(type, title, chtxt, btime):
    rec10d.rec10db.del_timeline(type=type, title=title, chtxt=chtxt, btime=btime)
def add_auto_keyword(chtxt,title,btime,etime):
    rec10d.rec10db.add_auto_timeline_keyword(chtxt, title, btime, etime)
def add_auto_bayes(chtxt,title,btime,etime,point):
    rec10d.rec10db.add_auto_timeline_bayes(chtxt, title, btime, etime,point)
def getnow(dhour):
    dhour = int(dhour)
    dminutes = 60 * dhour
    dminutes = str(dminutes)
    return rec10d.rec10db.select_bytime_timeline(dminutes)
def getnow_minutes(dminutes):
    return rec10d.rec10db.select_bytime_timeline(dminutes)
def countRecNow(dhour):
    d = getnow(dhour)
    ret = 0
    for i in d:
        t = i['type']
        if t == "key" or t == "keyevery" or t == "rec" or t == "res":
            ret = ret + 1
    return ret
def countRecNow_minutes(dminutes):
    d = getnow_minutes(dminutes)
    ret = 0
    for i in d:
        t = i['type']
        if t == "key" or t == "keyevery" or t == "rec" or t == "res":
            ret = ret + 1
    return ret
def countRecNow_minutes_BSCS(dminutes):
    d = getnow_minutes(dminutes)
    ret = 0
    for i in d:
        t = i['type']
        if t == "key" or t == "keyevery" or t == "rec" or t == "res":
            if len(chdb.chtxtsearch(i['chtxt'])['ch']) > 2:
                ret = ret + 1
    return ret
def countRecNow_minutes_TE(dminutes):
    d = getnow_minutes(dminutes)
    ret = 0
    for i in d:
        t = i['type']
        if t == "key" or t == "keyevery" or t == "rec" or t == "res":
            if len(chdb.chtxtsearch(i['chtxt'])['ch']) < 3:
                ret = ret + 1
    return ret
def delete_old(dhour):
    """
    delete keys except recdblist.REC_MISS_ENCODE and recdblist.REC_KEYWORD_EVERY_SOME_DAYS before dhour hours from now.
    """
    rec10d.rec10db.delete_old_timeline(dhour)
def delete_old_auto_keyword(dhour):
    rec10d.rec10db.delete_old_auto_timeline_keyword(dhour)
def delete_old_auto_bayes(dhour):
    rec10d.rec10db.delete_old_auto_timeline_bayes(dhour)
def getall():
    return rec10d.rec10db.select_all_timeline()
def rec_reclog(title,chtxt,btime,etime,opt,exp,longexp,category):
    rec10d.rec10db.add_in_timeline_log(chtxt,title,btime,etime,opt,exp,longexp,category)
def get_key():
    return rec10d.rec10db.select_all_in_auto_jbk_key()
